@@ -3,8 +3,9 @@ import ujson as json
 from loguru import logger
 import os
 from mwbot import error
-from .prototype import WikiSectionDict
 from typing import Union
+from .prototype import WikiSectionList
+
 
 class Bot:
     '''(https://www.mediawiki.org/wiki/API:Main_page/zh)[Mediawiki文档]
@@ -17,20 +18,16 @@ class Bot:
     :param password(`str`) : 用户密码'''
 
     # 成员变量
-    def __init__(self,
-                sitename:str,
-                api:str,
-                index:str,
-                username:str,
-                password:str):
+    def __init__(self, sitename: str, api: str, index: str, username: str, password: str):
         '''同步构造函数'''
         self.sitename = sitename
         self.api = api
         self.index = index
         self.username = username
         self.password = password
-        timeout = httpx.Timeout(10.0, connect=60.0, read=60.0, write=60.0, pool=60.0)
-        self.client = httpx.AsyncClient(verify=False,timeout=timeout)
+        timeout = httpx.Timeout(
+            10.0, connect=60.0, read=60.0, write=60.0, pool=60.0)
+        self.client = httpx.AsyncClient(verify=False, timeout=timeout)
         self.headers = {
             'User-Agent': f"{self.username}/mwbot"}
 
@@ -38,9 +35,10 @@ class Bot:
         '''异步析构函数'''
         await self.client.aclose()
 
-    async def fetch_token(self, type:str)->str:
+    async def fetch_token(self, type: str) -> str:
         '''根据不同的type类型返回对应的token
-        :param type(`str`) : token的类型'''
+        :param: type(`str`)  token的类型'''
+
         data = {
             'action': "query",
             'meta': "tokens",
@@ -53,9 +51,10 @@ class Bot:
         location = type + "token"
         return token['query']['tokens'][location]
 
-    async def login(self)->None:
+    async def login(self) -> None:
         '''登录
         :use: await bot.login()'''
+
         login_data = {
             'action': "login",
             'lgname': self.username,
@@ -63,19 +62,21 @@ class Bot:
             'lgtoken': await self.fetch_token(type="login"),
             'format': "json"
         }
-        login = await self.client.post(url=self.api, data=login_data,headers=self.headers)
+        login = await self.client.post(url=self.api, data=login_data, headers=self.headers)
         login = login.json()
         if login['login']['result'] == "Success":
-            logger.success(f'您已登录至{self.sitename}, {login["login"]["lgusername"]}!')
+            logger.success(
+                f'您已登录至{self.sitename}, {login["login"]["lgusername"]}！')
         else:
-            raise error.mwbotLoginERROR(f"用户{self.username}登录至{self.sitename}中出现了错误。\n{login}")
+            raise error.mwbotLoginError(
+                f"用户{self.username}登录至{self.sitename}中出现了错误。\n{login}")
 
-    async def get_data(self, title:str)->dict:
+    async def get_data(self, title: str) -> dict:
         '''获取页面的数据
         :use: data = await bot.get_data(title)
         :params: title(`str`)：页面名
-        :return: `dict`
-        '''
+        :return: `dict` '''
+
         data = {
             "action": "query",
             "prop": "revisions",
@@ -90,13 +91,12 @@ class Bot:
         text = text["query"]["pages"][0]
         return text
 
-    async def get_page_text(self,title:str,section:Union[str,int]='')->str:
+    async def get_page_text(self, title: str, section: Union[str, int] = '') -> Union[str, None]:
         '''获取页面中的文本
         :use: text = bot.get_page_text(title)
         :params: title(`str`)：页面标题
         :params: section(`Union[str,int]`)：*可选项* 编辑章节号
-        :return: str/None
-        '''
+        :return: str/None '''
         act = await self.client.post(url=f"{self.index}?action=raw&title={title}&section={str(section)}", headers=self.headers)
         if act.status_code == 404:
             logger.warning(f"请检查get_page_text传入的页面是否在{self.sitename}存在。")
@@ -104,78 +104,97 @@ class Bot:
         else:
             return str(act.text)
 
-    async def edit_page(self,title:str,text:str,summary:str="", **kwargs):
+    async def edit_page(self, title: str, **kwargs):
         '''编辑一个页面
         :use: await bot.edit_page(title,text,summary)
         :params: title(`str`) : 编辑页面的标题，不自动重定向
         :params: text(`str`) : 编辑页面的内容
         :params: summary(`str`) : 编辑摘要
         :params: ...
-        :return: None
-        '''
+        :return: None '''
+
         data = {
             "action": "edit",
             "minor": True,
             "bot": True,
             "format": "json",
+            "token": await self.fetch_token(type="csrf"),
             "title": title,
-            "text": text,
-            "summary":summary
         }
         for key, value in kwargs.items():
             key = str(key)
             value = str(value)
             data[key] = value
-        data["token"] = await self.fetch_token(type="csrf")
         act = await self.client.post(url=self.api, data=data, headers=self.headers)
-        logger.info(f"已向{self.sitename}发送页面[[{title}]]的编辑请求.")
-        act = act.json()
-        if ('edit'['result'] in act) & (act['edit'][result]== "Success"):
-            logger.success(f'成功编辑页面 [[{data["title"]}]].')
+        logger.info(f"已向{self.sitename}发送页面[[{title}]]的编辑请求。")
+        act: dict = act.json()
+        if act.get('edit', {}).get("result", None) != None:
+            if act['edit']['result'] == "Success":
+                logger.success(f'成功编辑页面 [[{data["title"]}]]。')
+            else:
+                logger.debug(act)
+                return False
         else:
             logger.debug(act)
+            return False
 
-    async def create_page(self,title:str,text:str,summary:str="")->bool:
+    async def create_page(self, title: str, text: str, summary: str = "") -> bool:
         '''创建页面
         :use: bot.create_page(title,text,summary)
         :params: title(`str`) : 创建页面的标题
         :params: text(`str`) : 创建页面的内容
         :params: summary(`str`) : 编辑摘要
-        :return: bool：指示创建是否成功（True为成功，False为失败）
-        '''
+        :return: bool：指示创建是否成功（True为成功，False为失败）'''
+
         deal = await self.get_data(title=title)
         if "missing" in deal:
-            await self.edit_page(title=title,text=text,summary=summary)
-            return False
-        else:
-            logger.warning(f"跳过创建[[{title}]].")
+            await self.edit_page(title=title, text=text, summary=summary)
             return True
+        else:
+            logger.warning(f"跳过创建[[{title}]]。")
+            return False
 
-    async def upload_local(self,local_name,local_path,web_name,text="", **kwargs):
-        '''从本地上传一个文件.'''
+    async def upload_local(self, filepath, servername=None,
+                           text="", comment="", **kwargs) -> bool:
+        '''从本地上传一个文件。'''
+        if servername is None:
+            servername = os.path.basename(filepath)
         data = {
             "action": "upload",
-            "filename": web_name,
-            "format": "json",
-            "token": self.fetch_token(type="csrf"),
+            "filename": servername,
+            "token": await self.fetch_token(type="csrf"),
+            "text": text,
+            "comment": comment,
             "ignorewarnings": True,
             "watchlist": "nochange",
-            "async": True
+            "async": True,
+            "format": "json",
         }
         for key, value in kwargs.items():
             key = str(key)
             value = str(value)
             data[key] = value
-        FILE = {'file': (local_name, open(local_path, 'rb'), 'multipart/form-data')}
+        FILE = {'file': (os.path.basename(filepath),
+                         open(filepath, 'rb'),
+                         'multipart/form-data')}
         act = await self.client.post(url=self.api, data=data, headers=self.headers, files=FILE)
         act = act.json()
-        if act["upload"]["result"] == "Success":
-            logger.success(f'Upload {local_name}=>[[File:{web_name}]] successfully.')
+        if act.get('upload', {}).get("result", None) != None:
+            if act['upload']['result'] == "Success":
+                logger.success(
+                    f'成功上传本地文件 {filepath} 至 [[{self.sitename}:文件:{servername}]]。')
+                return True
+            else:
+                logger.debug(
+                    f"上传本地文件 {filepath} 至 [[{self.sitename}:文件:{servername}]]失败。\n{act}")
+                return False
         else:
             logger.debug(act)
+            return False
 
-    async def purge(self,title:str,**kwargs)->None:
+    async def purge(self, title: str, **kwargs) -> None:
         '''刷新页面'''
+
         data = {
             "action": "purge",
             "titles": title,
@@ -185,12 +204,13 @@ class Bot:
             key = str(key)
             value = str(value)
             data[key] = value
-        act = await self.client.post(url=self.api, data=data,headers=self.headers)
+        act = await self.client.post(url=self.api, data=data, headers=self.headers)
         act = act.json()
-        logger.success(f"成功刷新页面 [[{title}]].")
+        logger.success(f"成功刷新页面 [[{title}]]。")
 
     async def parse(self, title, **kwargs):
         '''解析'''
+
         data = {
             "format": "json",
             "page": title,
@@ -203,46 +223,47 @@ class Bot:
         act = await self.client.post(url=self.api, data=data, headers=self.headers)
         return act.json()
 
-    async def get_sections(self, title:str)->Union[WikiSectionDict,bool]:
+    async def get_sections(self, title: str) -> Union[WikiSectionList, bool]:
         result = await self.parse(title=title, prop='sections')
         result = result['parse']['sections']
         result_list = []
         for i in result:
             result_list.append(i['line'])
         if result_list:
-            return WikiSectionDict(result_list)
+            return WikiSectionList(result_list)
         else:
             return False
-            logger.warning(f'页面 [[{title}]] 中没有子章节!')
+            logger.warning(f'页面 [[{title}]] 中没有子章节！')
 
-    async def deal_flow(self,title,cotmoderationState,cotreason="标记"):
+    async def deal_flow(self, title, cotmoderationState, cotreason="标记"):
         data = {
             "action": "flow",
             "page": str(title),
-            "submodule":"lock-topic", 
-            "cotmoderationState":cotmoderationState,
-            "cotreason":cotreason,
+            "submodule": "lock-topic",
+            "cotmoderationState": cotmoderationState,
+            "cotreason": cotreason,
             "format": "json",
-            "token":self.fetch_token(type="csrf")
+            "token": self.fetch_token(type="csrf")
         }
         act = await self.client.post(url=self.api, data=data, headers=self.headers).json()
-        logger.success(f"{cotmoderationState} the flow {title} successfully.({cotreason})")
+        logger.success(
+            f"{cotmoderationState} the flow {title} successfully.({cotreason})")
 
-    async def reply_flow(self,title,content):
+    async def reply_flow(self, title, content):
         data = {
             "action": "flow",
-            "submodule":"reply",
-            "page":title,
+            "submodule": "reply",
+            "page": title,
             "repreplyTo": str(title),
-            "repcontent":str(content),
-            "repformat":"wikitext",
+            "repcontent": str(content),
+            "repformat": "wikitext",
             "format": "json",
-            "token":self.fetch_token(type="csrf")
+            "token": self.fetch_token(type="csrf")
         }
         act = await self.client.post(url=self.api, data=data, headers=self.headers).json()
         logger.success(f"Reply the flow {title} successfully.")
 
-    async def rc(self,namespace:str="0",limit:Union[str,int]=50,days:Union[str,int]=5):
+    async def rc(self, namespace: str = "0", limit: Union[str, int] = 50, days: Union[str, int] = 5):
         from xmltodict import parse as XMLParse
         data = {
             "action": "feedrecentchanges",
@@ -255,16 +276,16 @@ class Bot:
         act = await self.client.post(url=self.index, data=data, headers=self.headers).json()
         return XMLParse(act.content)["feed"]["entry"]
 
-    async def search(self, txt:str, namespace:str="0", sroffset:str="0", **kwargs):
+    async def search(self, txt: str, namespace: str = "0", sroffset: str = "0", **kwargs):
         data = {
-            "action":"query",
-            "list":"search",
-            "srsearch":txt,
-            "srlimit":"max",
-            "utf8":"",
-            "srnamespace":namespace,
-            "srwhat":"text",
-            "sroffset":sroffset,
+            "action": "query",
+            "list": "search",
+            "srsearch": txt,
+            "srlimit": "max",
+            "utf8": "",
+            "srnamespace": namespace,
+            "srwhat": "text",
+            "sroffset": sroffset,
             "format": "json",
         }
         for key, value in kwargs.items():
@@ -274,33 +295,34 @@ class Bot:
         act = await self.client.post(url=self.api, data=data, headers=self.headers)
         act = act.json()
         rl = []
-        if act["query"]["search"] != False: 
+        if act["query"]["search"] != False:
             for i in act["query"]["search"]:
-                rl.append(i["title"])    
+                rl.append(i["title"])
         if "continue" in act:
-            temp = await self.search(txt=txt,namespace=namespace,sroffset=(int(sroffset)+1),**kwargs)
-            for i in temp:rl.append(i)
+            temp = await self.search(txt=txt, namespace=namespace, sroffset=(int(sroffset)+1), **kwargs)
+            for i in temp:
+                rl.append(i)
         return rl
 
-    async def ask(self,query:str,api_version:int=2):
+    async def ask(self, query: str, api_version: int = 2):
         data = {
-            "action":"ask",
-            "query":query,
-            "api_version":api_version,
+            "action": "ask",
+            "query": query,
+            "api_version": api_version,
             "format": "json",
         }
         act = await self.client.post(url=self.api, data=data, headers=self.headers)
         act = act.json()
         return act["query"]
 
-    async def protect(self,title,protections,expiry:str="infinite",reason:str="",**kwargs):
+    async def protect(self, title, protections, expiry: str = "infinite", reason: str = "", **kwargs):
         data = {
             "action": "protect",
             "format": "json",
             "title": title,
-            "protections":protections,
-            "expiry":expiry,
-            "reason":reason
+            "protections": protections,
+            "expiry": expiry,
+            "reason": reason
         }
         for key, value in kwargs.items():
             key = str(key)
@@ -311,16 +333,19 @@ class Bot:
         act = await self.client.post(url=self.api, data=data, headers=self.headers)
         act = act.json()
         return act["protect"]
-    
-    async def user_contributions(self,user:str,**kwargs)->list:
+
+    async def user_contributions(self, user: str, uccontinue: str = "", **kwargs) -> list:
         data = {
             "action": "query",
             "list": "usercontribs",
             "ucuser": user,
-            "uclimit": 500,
-            "ucprop": "commentflags|ids|parsedcomment|patrolled|size|sizediff|tags|timestamp|title",
+            "uclimit": "max",
+            "ucprop": "title|ids|size|sizediff|tags|timestamp",
+            "ucnamespace": "*",
             "format": "json"
         }
+        if uccontinue != "":
+            data["uccontinue"] = uccontinue
         for key, value in kwargs.items():
             key = str(key)
             value = str(value)
@@ -328,10 +353,11 @@ class Bot:
         act = await self.client.post(url=self.api, data=data, headers=self.headers)
         act = act.json()
         rl = []
-        if act["query"]["usercontribs"] != False: 
+        if act["query"]["usercontribs"] != False:
             for i in act["query"]["usercontribs"]:
-                rl.append(i["title"])    
+                rl.append(i)
         if "continue" in act:
-            temp = await self.user_contributions(user=user,uccontinue=act["continue"]["uccontinue"],**kwargs)
-            for i in temp:rl.append(i)
-        return rl
\ No newline at end of file
+            temp = await self.user_contributions(user=user, uccontinue=act["continue"]["uccontinue"], **kwargs)
+            for i in temp:
+                rl.append(i)
+        return rl
